package jalview.datamodel;

import static org.testng.AssertJUnit.assertFalse;
import static org.testng.AssertJUnit.assertTrue;

import jalview.util.MapList;

import org.testng.annotations.Test;

public class DBRefEntryTest
{

  /**
   * Tests for the method that compares equality of reference (but not mapping)
   */
  @Test
  public void testEqualRef()
  {
    DBRefEntry ref1 = new DBRefEntry("UNIPROT", "1", "V71633");
    assertTrue(ref1.equalRef(ref1));
    assertFalse(ref1.equalRef(null));

    // comparison is not case sensitive
    DBRefEntry ref2 = new DBRefEntry("uniprot", "1", "v71633");
    assertTrue(ref1.equalRef(ref2));
    assertTrue(ref2.equalRef(ref1));

    // source, version and accessionid must match
    assertFalse(ref1.equalRef(new DBRefEntry("UNIPRO", "1", "V71633")));
    assertFalse(ref1.equalRef(new DBRefEntry("UNIPROT", "2", "V71633")));
    assertFalse(ref1.equalRef(new DBRefEntry("UNIPROT", "1", "V71632")));

    // presence of or differences in mappings are ignored
    ref1.setMap(new Mapping(new MapList(new int[]
    { 1, 3 }, new int[]
    { 1, 1 }, 3, 1)));
    assertTrue(ref1.equalRef(ref2));
    assertTrue(ref2.equalRef(ref1));
    ref1.setMap(new Mapping(new MapList(new int[]
    { 1, 6 }, new int[]
    { 1, 2 }, 3, 1)));
    assertTrue(ref1.equalRef(ref2));
    assertTrue(ref2.equalRef(ref1));
  }
}
